Fudgy replaces real objects with fakes (mocks, stubs) for testing purposes.

It is a drop-in replacement for the original [Fudge](https://github.com/fudge-py/fudge) package by [Kumar McMillan](https://github.com/kumar303). Unlike the original, it supports modern versions of Python (3.9+).

Install Fudgy with `pip install fudgy` instead of `pip install fudge`. Then, use it exactly as you would the original version.

[Documentation](https://fudge.readthedocs.org/en/latest/)
